pub enum OverflowedContentDirection {
RightToLeft,
LeftToRight,
}Expand description
The direction in which OverflowedContent scrolls.
Variants
RightToLeft
Content enters from the right edge and scrolls to the left.
LeftToRight
Content starts at the left edge and scrolls to the right.